@@ -302,15 +302,17 @@ def get_model_max_id_in_db(model):
 
     if ordering:
         if ordering[0] == '-id':
-            max_id = model.objects.first().id
+            obj = model.objects.first()
+            max_id = obj.id if obj else 0
             ret = max_id + 1
             return ret
         if ordering[0] == 'id':
-            max_id = model.objects.last().id
+            obj = model.objects.last()
+            max_id = obj.id if obj else 0
             ret = max_id + 1
             return ret
-
-    max_id = model.objects.all().aggregate(max_id=Max('id')).get('max_id')
+    qs = model.objects.all()
+    max_id = qs.aggregate(max_id=Max('id')).get('max_id')  if qs.count() else 0
     ret = max_id + 1
     return ret
 
